/* eslint-disable react/destructuring-assignment */ 'use client';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { FieldLabel } from '@payloadcms/ui/forms/FieldLabel';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
import React, { useCallback } from 'react';
import { CodeEditor } from '../../elements/CodeEditor/index.js';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { fieldBaseClass } from '../shared/index.js';
const prismToMonacoLanguageMap = {
    js: 'javascript',
    ts: 'typescript'
};
const baseClass = 'code-field';
const CodeField = (props)=>{
    const { name, AfterInput, BeforeInput, CustomDescription, CustomError, CustomLabel, className, descriptionProps, editorOptions = {}, errorProps, label, labelProps, language = 'javascript', path: pathFromProps, readOnly: readOnlyFromProps, required, style, validate, width } = props;
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const { path, setValue, showError, value } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            showError && 'error',
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    }), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("div", null, BeforeInput, /*#__PURE__*/ React.createElement(CodeEditor, {
        defaultLanguage: prismToMonacoLanguageMap[language] || language,
        onChange: readOnly ? ()=>null : (val)=>setValue(val),
        options: editorOptions,
        readOnly: readOnly,
        value: value || ''
    }), AfterInput), CustomDescription ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const Code = withCondition(CodeField);

//# sourceMappingURL=index.js.map