'use client';
import { getTranslation } from '@payloadcms/translations';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { FieldLabel } from '@payloadcms/ui/forms/FieldLabel';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
import React, { useCallback } from 'react';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { fieldBaseClass } from '../shared/index.js';
const EmailField = (props)=>{
    const { name, AfterInput, BeforeInput, CustomDescription, CustomError, CustomLabel, autoComplete, className, descriptionProps, errorProps, label, labelProps, path: pathFromProps, placeholder, readOnly: readOnlyFromProps, required, style, validate, width } = props;
    const { i18n } = useTranslation();
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const { path, setValue, showError, value } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            'email',
            className,
            showError && 'error',
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    }), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("div", null, BeforeInput, /*#__PURE__*/ React.createElement("input", {
        autoComplete: autoComplete,
        disabled: readOnly,
        id: `field-${path.replace(/\./g, '__')}`,
        name: path,
        onChange: setValue,
        placeholder: getTranslation(placeholder, i18n),
        type: "email",
        value: value || ''
    }), AfterInput), CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const Email = withCondition(EmailField);

//# sourceMappingURL=index.js.map