'use client';
import React, { useCallback, useEffect, useState } from 'react';
import { CodeEditor } from '../../elements/CodeEditor/index.js';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { fieldBaseClass } from '../shared/index.js';
const baseClass = 'json-field';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
const JSONFieldComponent = (props)=>{
    const { name, AfterInput, BeforeInput, CustomDescription, CustomError, CustomLabel, className, descriptionProps, editorOptions, errorProps, jsonSchema, label, labelProps, path: pathFromProps, readOnly: readOnlyFromProps, required, style, validate, width } = props;
    const [stringValue, setStringValue] = useState();
    const [jsonError, setJsonError] = useState();
    const [hasLoadedValue, setHasLoadedValue] = useState(false);
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') return validate(value, {
            ...options,
            jsonError,
            required
        });
    }, [
        validate,
        required,
        jsonError
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const { initialValue, path, setValue, showError, value } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    const handleMount = useCallback((editor, monaco)=>{
        if (!jsonSchema) return;
        const existingSchemas = monaco.languages.json.jsonDefaults.diagnosticsOptions.schemas || [];
        const modelUri = monaco.Uri.parse(jsonSchema.uri);
        const model = monaco.editor.createModel(JSON.stringify(value, null, 2), 'json', modelUri);
        monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
            enableSchemaRequest: true,
            schemas: [
                ...existingSchemas,
                jsonSchema
            ],
            validate: true
        });
        editor.setModel(model);
    }, [
        jsonSchema,
        value
    ]);
    const handleChange = useCallback((val)=>{
        if (readOnly) return;
        setStringValue(val);
        try {
            setValue(val ? JSON.parse(val) : null);
            setJsonError(undefined);
        } catch (e) {
            setValue(val ? val : null);
            setJsonError(e);
        }
    }, [
        readOnly,
        setValue,
        setStringValue
    ]);
    useEffect(()=>{
        if (hasLoadedValue) return;
        setStringValue(value || initialValue ? JSON.stringify(value ? value : initialValue, null, 2) : '');
        setHasLoadedValue(true);
    }, [
        initialValue,
        value,
        hasLoadedValue
    ]);
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            showError && 'error',
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    }), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("div", null, BeforeInput, /*#__PURE__*/ React.createElement(CodeEditor, {
        defaultLanguage: "json",
        onChange: handleChange,
        onMount: handleMount,
        options: editorOptions,
        readOnly: readOnly,
        value: stringValue
    }), AfterInput), CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const JSONField = withCondition(JSONFieldComponent);

//# sourceMappingURL=index.js.map