/* eslint-disable react/destructuring-assignment */ /* eslint-disable react-hooks/exhaustive-deps */ 'use client';
import { optionIsObject } from 'payload/types';
import React, { useCallback } from 'react';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useForm } from '../../forms/Form/context.js';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { fieldBaseClass } from '../shared/index.js';
import { Radio } from './Radio/index.js';
const baseClass = 'radio-group';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
const RadioGroupField = (props)=>{
    const { name, CustomDescription, CustomError, CustomLabel, className, descriptionProps, errorProps, label, labelProps, layout = 'horizontal', onChange: onChangeFromProps, options = [], path: pathFromProps, readOnly: readOnlyFromProps, required, style, validate, value: valueFromProps, width } = props;
    const { uuid } = useForm();
    const memoizedValidate = useCallback((value, validationOptions)=>{
        if (typeof validate === 'function') return validate(value, {
            ...validationOptions,
            options,
            required
        });
    }, [
        validate,
        options,
        required
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const { path, setValue, showError, value: valueFromContext } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    const value = valueFromContext || valueFromProps;
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            `${baseClass}--layout-${layout}`,
            showError && 'error',
            readOnly && `${baseClass}--read-only`
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement("div", {
        className: `${baseClass}__error-wrap`
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    })), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("ul", {
        className: `${baseClass}--group`,
        id: `field-${path.replace(/\./g, '__')}`
    }, options.map((option)=>{
        let optionValue = '';
        if (optionIsObject(option)) {
            optionValue = option.value;
        } else {
            optionValue = option;
        }
        const isSelected = String(optionValue) === String(value);
        const id = `field-${path}-${optionValue}${uuid ? `-${uuid}` : ''}`;
        return /*#__PURE__*/ React.createElement("li", {
            key: `${path} - ${optionValue}`
        }, /*#__PURE__*/ React.createElement(Radio, {
            id: id,
            isSelected: isSelected,
            onChange: ()=>{
                if (typeof onChangeFromProps === 'function') {
                    onChangeFromProps(optionValue);
                }
                if (!readOnly) {
                    setValue(optionValue);
                }
            },
            option: optionIsObject(option) ? option : {
                label: option,
                value: option
            },
            path: path,
            uuid: uuid
        }));
    })), CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const RadioGroup = withCondition(RadioGroupField);

//# sourceMappingURL=index.js.map