'use client';
import React from 'react';
const ModifyClientFunctionContext = /*#__PURE__*/ React.createContext({
    addClientFunction: ()=>null,
    removeClientFunction: ()=>null
});
const ClientFunctionsContext = /*#__PURE__*/ React.createContext({});
export const ClientFunctionProvider = ({ children })=>{
    const [clientFunctions, setClientFunctions] = React.useState({});
    const addClientFunction = React.useCallback((args)=>{
        setClientFunctions((state)=>{
            const newState = {
                ...state
            };
            newState[args.key] = args.func;
            return newState;
        });
    }, []);
    const removeClientFunction = React.useCallback((args)=>{
        setClientFunctions((state)=>{
            const newState = {
                ...state
            };
            delete newState[args.key];
            return newState;
        });
    }, []);
    return /*#__PURE__*/ React.createElement(ModifyClientFunctionContext.Provider, {
        value: {
            addClientFunction,
            removeClientFunction
        }
    }, /*#__PURE__*/ React.createElement(ClientFunctionsContext.Provider, {
        value: clientFunctions
    }, children));
};
export const useAddClientFunction = (key, func)=>{
    const { addClientFunction, removeClientFunction } = React.useContext(ModifyClientFunctionContext);
    React.useEffect(()=>{
        addClientFunction({
            func,
            key
        });
        return ()=>{
            removeClientFunction({
                func,
                key
            });
        };
    }, [
        func,
        key,
        addClientFunction,
        removeClientFunction
    ]);
};
export const useClientFunctions = ()=>{
    return React.useContext(ClientFunctionsContext);
};

//# sourceMappingURL=index.js.map