import React from 'react';
import { WithServerSideProps as WithServerSidePropsGeneric } from './WithServerSideProps.js';
import { mapCollections } from './collections.js';
import { mapGlobals } from './globals.js';
export const buildComponentMap = (args)=>{
    const { DefaultEditView, DefaultListView, children, config, i18n, payload, readOnly } = args;
    const WithServerSideProps = ({ Component, ...rest })=>{
        return /*#__PURE__*/ React.createElement(WithServerSidePropsGeneric, {
            Component: Component,
            payload: payload,
            ...rest
        });
    };
    const collections = mapCollections({
        DefaultEditView,
        DefaultListView,
        WithServerSideProps,
        collections: config.collections,
        config,
        i18n,
        readOnly
    });
    const globals = mapGlobals({
        DefaultEditView,
        WithServerSideProps,
        config,
        globals: config.globals,
        i18n,
        readOnly
    });
    const NestProviders = ({ children, providers })=>{
        const Component = providers[0];
        if (providers.length > 1) {
            return /*#__PURE__*/ React.createElement(Component, null, /*#__PURE__*/ React.createElement(NestProviders, {
                providers: providers.slice(1)
            }, children));
        }
        return /*#__PURE__*/ React.createElement(Component, null, children);
    };
    const LogoutButtonComponent = config.admin?.components?.logout?.Button;
    const LogoutButton = LogoutButtonComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
        Component: LogoutButtonComponent
    }) : null;
    const IconComponent = config.admin?.components?.graphics?.Icon;
    const Icon = IconComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
        Component: IconComponent
    }) : null;
    return {
        componentMap: {
            Icon,
            LogoutButton,
            actions: config.admin?.components?.actions?.map((Component)=>/*#__PURE__*/ React.createElement(WithServerSideProps, {
                    Component: Component
                })),
            collections,
            globals
        },
        wrappedChildren: Array.isArray(config.admin?.components?.providers) && config.admin?.components?.providers.length > 0 ? /*#__PURE__*/ React.createElement(NestProviders, {
            providers: config.admin?.components?.providers
        }, children) : children
    };
};

//# sourceMappingURL=index.js.map